@@ -17,6 +17,7 @@ package jp.sf.pal.myfaces.portlet;
 
 import java.io.IOException;
 
+import javax.faces.FacesException;
 import javax.faces.FactoryFinder;
 import javax.faces.application.Application;
 import javax.faces.application.ApplicationFactory;
@@ -69,7 +70,7 @@ import org.apache.myfaces.webapp.webxml.WebXml;
  * 
  * Base Information:
  * @author  Stan Silvert (latest modification by Author: ssilvert )
- * @version Revision: 279594
+ * @version Revision: 369783
  */
 public class MyFacesGenericPortlet extends GenericPortlet
 {
@@ -403,15 +404,27 @@ public class MyFacesGenericPortlet extends GenericPortlet
         if (log.isTraceEnabled())
             log.trace("Non-faces request: contextPath = " + request.getContextPath());
         setContentType(request, response); // do this in case nonFacesRequest is called by a subclass
-        ApplicationFactory appFactory = (ApplicationFactory) FactoryFinder
-                .getFactory(FactoryFinder.APPLICATION_FACTORY);
-        Application application = appFactory.getApplication();
-        ViewHandler viewHandler = application.getViewHandler();
-        FacesContext facesContext = facesContext(request, response);
-        UIViewRoot viewRoot = viewHandler.createView(facesContext, view);
-        viewRoot.setViewId(view);
-        facesContext.setViewRoot(viewRoot);
-        lifecycle.render(facesContext);
+        try
+        {
+            ApplicationFactory appFactory = (ApplicationFactory) FactoryFinder
+                    .getFactory(FactoryFinder.APPLICATION_FACTORY);
+            Application application = appFactory.getApplication();
+            ViewHandler viewHandler = application.getViewHandler();
+            FacesContext facesContext = facesContext(request, response);
+            UIViewRoot viewRoot = viewHandler.createView(facesContext, view);
+            viewRoot.setViewId(view);
+            facesContext.setViewRoot(viewRoot);
+            lifecycle.render(facesContext);
+        }
+        catch (FacesException e)
+        {
+            throw new PortletException(e);
+        }
+        catch (RuntimeException e)
+        {
+            // it may occur when accept content-type is invalid.
+            throw new PortletException(e);
+        }
     }
 
     protected String selectDefaultView(RenderRequest request, RenderResponse response) throws PortletException
